Learn R Programming

ClustVarLV (version 1.3.2)

descrip_gp: Description of the clusters of variables

Description

Complementary function that provides for each cluster their correlation with their own cluster latent component and with the next neighbouring cluster latent component.

Usage

descrip_gp(resclv, X, K = NULL)

Arguments

resclv
resultat of CLV or CLV_kmeans
X
the initial matrix used in CLV or CLV_kmeans
K
the number of groups in the partition

Examples

Run this code
data(apples_sh)
resclvX <- CLV(X = apples_sh$senso, method = 1, sX = TRUE, graph = TRUE)
descrip_gp(resclvX, X = apples_sh$senso, K = 4)

Run the code above in your browser using DataLab