Learn R Programming

ClustVarLV (version 1.6.0)

get_sparseload: sparse loadings in each cluster when using the "sparselv" strategy

Description

Applies only on CLV_kmeans output with strategy="sparselv".

Usage

get_sparseload(resclv, type = "list")

Arguments

resclv

: result of CLV_kmeans()

type

: presented in the form of a "list" (one element by cluster, by default) or a "vector"

Value

sparse_loadings

the loadings of the variables for each latent variables when the "sparselv strategy is used.