Learn R Programming

ClustVarLV (version 1.3.2)

gpmb_on_pc: Representation of the variables and their group membership

Description

Loading plot of the variables from a Principal Components Analysis. The group membership of the variables is superimposed.

Usage

gpmb_on_pc(resclv, X, K = NULL, axeh = 1, axev = 2, label = FALSE,
  v_colors = NULL, v_symbol = FALSE, beside = FALSE)

Arguments

resclv
results of CLV.r or CLV_kmeans.r
X
the initial matrix
K
the number of groups in the partition
axeh
component number for the horizontal axis
axev
component number for the vertical axis
label
= TRUE :the column names in X are used as labels / = FALSE: no labels (by default)
v_colors
default NULL. If missing colors are given, by default
v_symbol
=TRUE : symbols are given isntead of colors for the identification of the groups/ =FALSE: no symbol (by default).
beside
=TRUE : a plot per cluster of variables, side-by-side/ =FALSE :an unique plot with all the variables with the identification of their group membership (by default).

Examples

Run this code
data(apples_sh)
resclvX <- CLV(X = apples_sh$senso, method = 1, sX = TRUE, graph = TRUE)
gpmb_on_pc(resclvX, X = apples_sh$senso, K = 4, axeh = 1, axev = 2)

Run the code above in your browser using DataLab