Learn R Programming

ClustVarLV (version 1.4.0)

stand_quali: Standardization of the qualitative variables

Description

Standardization of the qualitative variables

Usage

stand_quali(X.quali, metric = "chisq")

Arguments

X.quali
: a factor or a data frame with several factors
metric
: the metric to be used, i.e. each category is weighted by the inverse of the square-root of its relative frequency

Value

  • Xdisj.sd : a standardized matrix with as many columns as categories associated with the qualitative variables.