Usage
CLV_kmeans(X, Xu = NULL, Xr = NULL, method, sX = TRUE, sXr = FALSE,
sXu = FALSE, init, iter.max = 20, nstart = 100, strategy = "none",
rho = 0.3)
Arguments
X
The matrix of the variables to be clustered
Xu
The external variables associated with the columns of X
Xr
The external variables associated with the rows of X
method
The criterion to use in the cluster analysis.
1 : the squared covariance is used as a measure of proximity (directional groups).
2 : the covariance is used as a measure of proximity (local groups)
sX
TRUE/FALSE : standardization or not of the columns X (TRUE by default)
(predefined -> cX = TRUE : column-centering of X)
sXr
TRUE/FALSE : standardization or not of the columns Xr (FALSE by default)
(predefined -> cXr = TRUE : column-centering of Xr)
sXu
TRUE/FALSE : standardization or not of the columns Xu (FALSE by default)
(predefined -> cXu= FALSE : no centering, Xu considered as a weight matrix)
init
a number i.e. the size of the partition, K,
or a vector of INTEGERS i.e. the group membership of each variable in the initial partition (integer between 1 and K)
iter.max
maximal number of iteration for the consolidation (20 by default)
nstart
nb of random initialisations in the case where init is a number (100 by default)
strategy
"none" (by default), or "kplusone" (an additional cluster for the noise variables),
or "sparselv" (zero loadings for the noise variables)
rho
a threshold of correlation between 0 and 1 (0.3 by default)