get_sparseload: sparse loadings in each cluster when using the "sparselv" strategy
Description
Applies only on CLV_kmeans output with strategy="sparselv".
Usage
get_sparseload(resclv, type = "list")
Arguments
type
: presented in the form of a "list" (one element by cluster, by default) or a "vector"
Value
sparse_loadingsthe loadings of the variables for each latent variables when the "sparselv strategy is used.