= TRUE :the column names in X are used as labels / = FALSE: no labels (by default)
v_colors
default NULL. If missing colors are given, by default
v_symbol
=TRUE : symbols are given isntead of colors for the identification of the groups/ =FALSE: no symbol (by default).
beside
=TRUE : a plot per cluster of variables, side-by-side/ =FALSE :an unique plot with all the variables with the identification of their group membership (by default).